# ovs-dbg

Scripts to help debug OVS and OVN

Full documentation here: https://ovs-dbg.readthedocs.io/en/latest

## ofparse

Ofparse parses the output of commands such as `ovs-ofproto dump-flows` and
prints the files in different outputs
